## What is it?

A small custom library that simplifies and speeds up routine actions when 
working with pandas, scikitlearn, catboost, etc...

The project is actively developing in proportion to my experience



